@@ -26,7 +26,6 @@ HAS_ACCOUNT_DEFAULT = _ACCOUNTDEFAULT()
 
 
 BoolSettings = Literal[
-    'allow_open_file_uris',
     'always_english_wikipedia',
     'always_english_wiktionary',
     'ascii_formatting',
@@ -66,7 +65,6 @@ BoolSettings = Literal[
     'print_status_in_chats',
     'remote_control',
     'show_main_menu',
-    'save_main_window_position',
     'send_on_ctrl_enter',
     'show_help_start_chat',
     'show_in_taskbar',
@@ -77,18 +75,14 @@ BoolSettings = Literal[
     'show_voice_message_button',
     'show_status_msgs_in_roster',
     'show_subject_on_join',
-    'show_transports_group',
     'show_trayicon',
-    'show_xhtml',
-    'showoffline',
     'sort_by_show_in_muc',
-    'sort_by_show_in_roster',
+    'sort_by_show_in_start_chat',
     'sounddnd',
     'sounds_on',
     'trayicon_notification_on_events',
     'use_keyring',
     'use_kib_mib',
-    'use_libappindicator',
     'use_speller',
     'use_stun_server',
     'use_urgency_hint',
@@ -108,11 +102,6 @@ IntSettings = Literal[
     'groupchat_roster_width',
     'mainwin_height',
     'mainwin_width',
-    'mainwin_x_position',
-    'mainwin_y_position',
-    'notification_position_x',
-    'notification_position_y',
-    'notification_timeout',
     'preview_max_file_size',
     'preview_size',
 ]
@@ -161,9 +150,9 @@ AllSettingsT = str | int | float | bool | list[str]
 
 APP_SETTINGS: dict[str, str | int | float | bool | list[Any]] = {
     'additional_uri_schemes': '',
-    'allow_open_file_uris': False,
     'always_english_wikipedia': False,
     'always_english_wiktionary': True,
+    'app_font_size': 1.0,
     'ascii_formatting': True,
     'ask_online_status': False,
     'audio_input_device': 'autoaudiosrc ! volume name=gajim_vol',
@@ -186,7 +175,6 @@ APP_SETTINGS: dict[str, str | int | float | bool | list[Any]] = {
     'date_format': '%x',
     'date_time_format': '%c',
     'dev_force_bookmark_2': False,
-    'dev_use_message_label': True,
     'developer_modus': False,
     'dictionary_url': 'WIKTIONARY',
     'enable_emoji_shortcodes': True,
@@ -215,18 +203,13 @@ APP_SETTINGS: dict[str, str | int | float | bool | list[Any]] = {
     'latest_disco_addresses': '',
     'mainwin_height': 500,
     'mainwin_width': 1000,
-    'mainwin_x_position': 0,
-    'mainwin_y_position': 0,
     'action_on_close': 'hide',
     'muc_highlight_words': '',
     'muc_prefer_direct_msg': True,
     'muclumbus_api_http_uri': 'https://search.jabber.network/api/1.0/search',
     'muclumbus_api_jid': 'api@search.jabber.network',
     'muclumbus_api_pref': 'http',
-    'notification_position_x': -1,
-    'notification_position_y': -1,
     'notification_preview_message': True,
-    'notification_timeout': 5,
     'notify_on_all_muc_messages': False,
     'notify_on_file_complete': True,
     'plugins_auto_update': False,
@@ -238,13 +221,12 @@ APP_SETTINGS: dict[str, str | int | float | bool | list[Any]] = {
     'preview_anonymous_muc': False,
     'preview_leftclick_action': 'open',
     'preview_max_file_size': 10485760,
-    'preview_size': 300,
+    'preview_size': 400,
     'preview_verify_https': True,
     'providers_list_url': 'https://data.xmpp.net/providers/v2/providers-B.json',
     'print_status_in_chats': False,
     'remote_control': False,
     'roster_theme': 'default',
-    'save_main_window_position': True,
     'search_engine': 'https://duckduckgo.com/?q=%s',
     'send_on_ctrl_enter': False,
     'show_help_start_chat': True,
@@ -258,12 +240,9 @@ APP_SETTINGS: dict[str, str | int | float | bool | list[Any]] = {
     'show_voice_message_button': True,
     'show_status_msgs_in_roster': True,
     'show_subject_on_join': True,
-    'show_transports_group': True,
     'show_trayicon': True,
-    'show_xhtml': True,
-    'showoffline': True,
     'sort_by_show_in_muc': False,
-    'sort_by_show_in_roster': True,
+    'sort_by_show_in_start_chat': True,
     'sounddnd': False,
     'sounds_on': True,
     'speller_language': '',
@@ -272,11 +251,9 @@ APP_SETTINGS: dict[str, str | int | float | bool | list[Any]] = {
     'trayicon_notification_on_events': True,
     'use_keyring': True,
     'use_kib_mib': False,
-    'use_libappindicator': True,
     'use_speller': True,
     'use_stun_server': False,
     'use_urgency_hint': True,
-    'app_font_size': 1.0,
     'video_framerate': '',
     'video_input_device': 'autovideosrc',
     'video_see_self': True,
@@ -300,7 +277,6 @@ BoolAccountSettings = Literal[
     'gc_send_marker_private_default',
     'gc_send_marker_public_default',
     'ignore_unknown_contacts',
-    'is_zeroconf',
     'publish_location',
     'publish_tune',
     'request_user_data',
@@ -310,6 +286,7 @@ BoolAccountSettings = Literal[
     'send_marker_default',
     'send_os_info',
     'send_time_info',
+    'sync_muc_blocks',
     'sync_with_global_status',
     'test_ft_proxies_on_startup',
     'use_custom_host',
@@ -343,10 +320,6 @@ StringAccountSettings = Literal[
     'roster_version',
     'send_chatstate_default',
     'subscription_request_msg',
-    'zeroconf_email',
-    'zeroconf_first_name',
-    'zeroconf_jabber_id',
-    'zeroconf_last_name',
 ]
 
 IntAccountSettings = Literal[
@@ -365,6 +338,8 @@ AllAccountSettings = Literal[BoolAccountSettings,
                              IntAccountSettings,
                              StringAccountSettings]
 
+AllAccountSettingsT = bool | int | str
+
 
 BoolGroupChatSettings = Literal[
     'notify_on_all_messages',
@@ -447,7 +422,6 @@ ACCOUNT_SETTINGS = {
         'gc_send_marker_public_default': False,
         'http_auth': 'ask',
         'ignore_unknown_contacts': False,
-        'is_zeroconf': False,
         'keyid': '',
         'keyname': '',
         'last_status': 'online',
@@ -468,15 +442,12 @@ ACCOUNT_SETTINGS = {
         'send_os_info': True,
         'send_time_info': True,
         'subscription_request_msg': '',
+        'sync_muc_blocks': True,
         'sync_with_global_status': True,
         'test_ft_proxies_on_startup': False,
         'use_custom_host': False,
         'use_ft_proxies': False,
         'use_plain_connection': False,
-        'zeroconf_email': '',
-        'zeroconf_first_name': '',
-        'zeroconf_jabber_id': '',
-        'zeroconf_last_name': '',
         'omemo_blind_trust': True,
     },
 
@@ -513,7 +484,7 @@ AllWorkspaceSettings = Literal[StringWorkspaceSettings, 'chats']
 class OpenChatSettingDetails(TypedDict):
     account: str
     jid: JID
-    type: str
+    type: Literal["chat", "groupchat", "pm"]
     pinned: bool
     position: int
 
@@ -643,7 +614,6 @@ ADVANCED_SETTINGS = {
         'additional_uri_schemes': _(
             'Clickable schemes in addition to the hard-coded list of '
             'IANA-registered ones. Space-separated, lower-case, no colons.'),
-        'allow_open_file_uris': _('Allows opening file:/ URIs when clicked.'),
         'always_english_wikipedia': '',
         'always_english_wiktionary': '',
         'ascii_formatting': _(
@@ -661,7 +631,6 @@ ADVANCED_SETTINGS = {
         'date_format': 'https://docs.python.org/3/library/time.html#time.strftime',  # noqa: E501
         'date_time_format': 'https://docs.python.org/3/library/time.html#time.strftime',  # noqa: E501
         'dev_force_bookmark_2': _('Force Bookmark 2 usage'),
-        'dev_use_message_label': '',
         'developer_modus': '',
         'dictionary_url': _(
             'Either a custom URL with %%s in it (where %%s is the word/phrase)'
@@ -694,15 +663,11 @@ ADVANCED_SETTINGS = {
             'API Preferences. Possible values: "http", "iq"'),
         'notification_preview_message': _(
             'Preview new messages in notification popup?'),
-        'notification_timeout': '',
         'notify_on_all_muc_messages': '',
         'plugins_repository_enabled': _(
             'If enabled, Gajim offers to download plugins hosted on gajim.org'),
         'providers_list_url': _(
             'Endpoint for retrieving a list of providers for sign up'),
-        'save_main_window_position': _(
-            'If enabled, Gajim will save the main window position when hiding '
-            'it, and restore it when showing the window again.'),
         'search_engine': '',
         'send_on_ctrl_enter': _(
             'Send message on Ctrl+Enter and make a new line with Enter.'),
@@ -712,8 +677,6 @@ ADVANCED_SETTINGS = {
             'Notify of events in the notification area.'),
         'use_kib_mib': _(
             'IEC standard says KiB = 1024 bytes, KB = 1000 bytes.'),
-        'use_libappindicator': _(
-            'Enables libappindicator, an alternative tray icon provider'),
         'use_stun_server': _(
             'If enabled, Gajim will try to use a STUN server when using Jingle.'
             ' The one in "stun_server" option, or the one given by '
